multiformats/hashes/sha256

This module only works on node and erlang The *_browser module will work on node and browser using the WebCrypto API

Values

pub fn digest(bytes: BitArray) -> hashes.Multihash
Search Document